@@ -5,7 +5,7 @@ use crate::cli::args::Scope;
 
 #[test]
 fn can_tell_me_if_its_global() {
-    let app = super::super::app::app();
+    let app = super::super::app::cli();
     let matches = app.get_matches_from(vec!["binary", "--scope=global"]);
     let actual = Args::from(matches);
 
@@ -15,7 +15,7 @@ fn can_tell_me_if_its_global() {
 
 #[quickcheck]
 fn it_can_give_me_a_shell(shell: Shell) -> bool {
-    let app = super::super::app::app();
+    let app = super::super::app::cli();
     let matches = app.get_matches_from(vec!["binary", "--completion", &String::from(shell)]);
     let actual = Args::from(matches);
 
@@ -24,7 +24,7 @@ fn it_can_give_me_a_shell(shell: Shell) -> bool {
 
 #[test]
 fn it_defaults_to_none() {
-    let app = super::super::app::app();
+    let app = super::super::app::cli();
     let matches = app.get_matches_from(vec!["binary"]);
     let actual = Args::from(matches);
 
@@ -33,7 +33,7 @@ fn it_defaults_to_none() {
 
 #[test]
 fn can_tell_me_if_its_local() {
-    let app = super::super::app::app();
+    let app = super::super::app::cli();
     let matches = app.get_matches_from(vec!["binary"]);
     let actual = Args::from(matches);
 
